@@ -6,21 +6,23 @@
 #' \tabular{ll}{
 #' Package: \tab TDMR\cr
 #' Type: \tab Package\cr
-#' Version: \tab 0.3.1\cr
-#' Date: \tab 01.06.2012\cr
+#' Version: \tab 1.0.0\cr
+#' Date: \tab 08.04.2013\cr
 #' License: \tab GPL (>= 2)\cr
 #' LazyLoad: \tab yes\cr
 #' }
 #'
 #' TDMR is a package for tuned data mining (predictive analytics, i.e. \bold{classification} and \bold{regression}). Its main features are: \cr
-#' 1) A variety of tuners, with special emphasis on \link{SPOT} (another well-known R package for parameter tuning), but also CMA-ES and other tuning algorithms. \cr
+#' 1) A variety of tuners, with special emphasis on \link{SPOT} (a well-known R package for parameter tuning), but also CMA-ES 
+#'    (package \code{\link{rCMA}}) and other tuning algorithms. \cr
 #' 2) Tuning of preprocessing (feature generation) parameters and model building parameters simultaneously.  \cr
 #' 3) Support for multiple tuning experiments (different settings, repetitions with different resamplings, ...).  \cr
-#' 4) Easy parallelization of those experiments with the help of R packages \code{snow} and \code{\link{parallel}}.
+#' 4) Easy parallelization of those experiments with the help of R packages \code{snow} and \code{\link{parallel}}.  \cr
+#' 5) Extensibility: New tuning parameters, new feature preprocessing tools, model builders and even new tuners can be added easily.
 #' 
 #' The main entry point functions are \code{\link{tdmClassifyLoop}}, \code{\link{tdmRegressLoop}} and \code{\link{tdmBigLoop}}. 
 #' See \code{\link{tdmOptsDefaultsSet}} and \code{\link{tdmDefaultsFill}} for an overview of adjustable TDMR-parameters.
-#'
+#'                                                
 #' @name TDMR-package
 #' @aliases TDMR
 #' @docType package
@@ -127,46 +129,63 @@ print2 <- function(opts, ...) {  if (opts$VERBOSE>=2) print(...); }
 
 ######################################################################################
 #
-# UTILITY FUNCTIONS FOR TDMclassifier AND TDMregressor OBJECTS
+# UTILITY FUNCTIONS FOR TDMenvir, TDMclassifier AND TDMregressor OBJECTS
 #
 ######################################################################################
 ######################################################################################
 
-predict.TDMclassifier <- function(result,newdata,...) {
-  predict(result$lastRes$lastModel,newdata,...);
+######################################################################################
+#' Make a prediction using the last model.
+#'
+#' Make a prediction with objects of class \code{\link{TDMenvir}}, \code{\link{TDMclassifier}},
+#' \code{\link{TDMregressor}}. The prediction is based on the (last) model trained during 
+#' \code{\link{unbiasedRun}}.
+#'
+#'   @param object  an object of class \code{\link{TDMenvir}}, \code{\link{TDMclassifier}},
+#'      \code{\link{TDMregressor}} containing in element \code{lastModel} the relevant model.
+#'   @param ... arguments passed on to the model's predict function. Usually the first argument of \code{...} should be 
+#'        \code{newdata}, a data frame for which new predictions are desired.
+#'   @return a vector with length \code{nrow(newdata)} containing the new predictions.
+#' @method predict TDMenvir
+#' @examples
+#'    \dontrun{
+#'        ## This example requires that demo04cpu.r is executed first (it will write demo04cpu.RData)
+#'        path <- paste(find.package("TDMR"), "demo01cpu/",sep="/");
+#'        tdm <- list(  filenameEnvT="demo04cpu.RData" );   # file with environment envT 
+#'        load(paste(path,tdm$filenameEnvT,sep="/"));
+#'                   
+#'        newdata=read.csv2(file=paste(path,"data/cpu.csv", sep=""), dec=".")[1:15,];     # take only the first 15 records
+#'        z=predict(envT,newdata);
+#'        print(z);
+#'    }
+#' @export
+predict.TDMenvir <- function(object,...) {
+  if (is.null(object$result)) stop("TDMenvir has no element 'result'");
+  if (is.null(object$result$lastRes)) stop("TDMenvir has no element 'result$lastRes'");
+  if (is.null(object$result$lastRes$lastModel)) stop("TDMenvir has no element 'result$lastRes$lastModel'. Consider to set tdm$U.saveModel=TRUE.");
+  predict(object$result$lastRes$lastModel,...);
+}
+######################################################################################
+#' @rdname predict.TDMenvir
+#' @method predict TDMclassifier
+#' @export
+# @keywords internal
+predict.TDMclassifier <- function(object,...) {
+  predict(object$lastRes$lastModel,...);
+}
+######################################################################################
+#' @rdname predict.TDMenvir
+#' @method predict TDMregressor
+#' @export
+predict.TDMregressor <- function(object,...) {
+  predict(object$lastRes$lastModel,...);
 }
 
-predict.TDMregressor <- function(result,newdata,...) {
-  predict(result$lastRes$lastModel,newdata,...);
-}
-
-#summary.TDMclassifier <- function(result,...) {
-#  cat("This is the TDMclassifier summary\n");
-#}
-
-
-RGainTST <- function(result) {
-  if (!inherits(result, "TDMclassifier"))
-        stop("This function is permitted only for objects of class `TDMclassifier'");
-  mean(result$R_test);
-}
-
-RGainTRN <- function(result) {
-  if (!inherits(result, "TDMclassifier"))
-        stop("This function is permitted only for objects of class `TDMclassifier'");
-  mean(result$R_train);
-}
-
-SRF <- function(result) {
-  if (!inherits(result, "TDMclassifier"))
-        stop("This function is permitted only for objects of class `TDMclassifier'");
-  result$lastRes$SRF;
-}
 
 ######################################################################################
 #' Return the list 'opts'.
 #'
-#' Returns the list \code{opts} from objects of class \code{\link{TDMclassifier}}, 
+#' Returns the list \code{opts} from objects of class \code{\link{TDMenvir}}, \code{\link{TDMclassifier}},
 #'                  \code{\link{TDMregressor}}, \code{\link[=tdmClassify]{tdmClass}} or \code{\link[=tdmRegress]{tdmRegre}}.
 #'   @param x  an object of class \code{\link{TDMclassifier}}, \code{\link[=tdmClassify]{tdmClass}}, 
 #'                                \code{\link{TDMregressor}} or \code{\link[=tdmRegress]{tdmRegre}}.
@@ -175,6 +194,16 @@ SRF <- function(result) {
 #' @export
 Opts <- function(x, ...)  UseMethod("Opts");
 
+######################################################################################
+#' @rdname Opts
+#' @method Opts TDMenvir
+#' @export
+# @keywords internal
+Opts.TDMenvir  <- function(x, ...) {
+  if (is.null(x$result)) stop("TDMenvir has no element 'result'");
+  if (is.null(x$result$lastRes)) stop("TDMenvir has no element 'result$lastRes'");
+  x$result$lastRes$opts;
+}
 ######################################################################################
 #' @rdname Opts
 #' @method Opts TDMclassifier
@@ -201,3 +230,29 @@ Opts.tdmRegre <- function(x,...) x$opts;
 #' @export
 # @keywords internal
 Opts.default <- function(x, ...)  cat("This is Opts.default\n");
+
+######################################################################################
+
+#summary.TDMclassifier <- function(result,...) {
+#  cat("This is the TDMclassifier summary\n");
+#}
+
+
+RGainTST <- function(result) {
+  if (!inherits(result, "TDMclassifier"))
+        stop("This function is permitted only for objects of class `TDMclassifier'");
+  mean(result$R_test);
+}
+
+RGainTRN <- function(result) {
+  if (!inherits(result, "TDMclassifier"))
+        stop("This function is permitted only for objects of class `TDMclassifier'");
+  mean(result$R_train);
+}
+
+SRF <- function(result) {
+  if (!inherits(result, "TDMclassifier"))
+        stop("This function is permitted only for objects of class `TDMclassifier'");
+  result$lastRes$SRF;
+}
+
